@@ -6,7 +6,7 @@ import sys
 from functools import partial
 import wx
 from wx.lib.agw import floatspin as fspin
-
+from . import myfloatspin as mspin
 from .icons import get_icon
 
 HAS_NUMPY = False
@@ -290,48 +290,31 @@ class FloatCtrl(wx.TextCtrl):
 
 
 def FloatSpin(parent, value=0, action=None, tooltip=None, size=(100, -1),
-              digits=1, increment=1, use_gtk3=False, **kws):
+              digits=1, increment=1, use_gtk3=True, use_local=False, **kws):
     """FloatSpin with action and tooltip"""
     if value is None:
         value = 0
 
-    # need to work this out better for GTK3 - lots of small
-    # differences with GTK2, but this one is the biggest headache.
-    # SpinCtrlDouble is like FloatSpin, but with every option
-    # having a slightly different name...
-    if use_gtk3 and 'gtk3' in wx.PlatformInfo:
-        maxval = kws.pop('max_val', None)
-        minval = kws.pop('min_val', None)
-        fmt = "%%%df" % digits
-        fs = wx.SpinCtrlDouble(parent, -1, value=fmt % value,
-                               size=(size[0]+40, size[1]),
-                               inc=increment, **kws)
-        fs.SetDigits(digits)
-        if minval is not None:
-            fs.SetMin(minval)
-        if maxval is not None:
-            fs.SetMax(maxval)
+    # for gtk3, don't use the horrible SpinCtrlDouble, but instead
+    # use a locally modified Float Spin with Bitmap Buttons
+    spin = mspin if (use_local or ('gtk3' in wx.PlatformInfo)) else fspin
 
-        if action is not None:
-            fs.Bind(wx.EVT_SPINCTRLDOUBLE, action)
-
-    else:
-        fs = fspin.FloatSpin(parent, -1, size=size, value=value,
-                             digits=digits, increment=increment, **kws)
-
-        if action is not None:
-            fs.Bind(fspin.EVT_FLOATSPIN, action)
+    fs = spin.FloatSpin(parent, -1, size=size, value=value,
+                        digits=digits, increment=increment, **kws)
+    if action is not None:
+        fs.Bind(spin.EVT_FLOATSPIN, action)
     if tooltip is not None:
         fs.SetToolTip(tooltip)
     return fs
 
-
 def FloatSpinWithPin(parent, value=0, pin_action=None,
                      tooltip='select point from plot', **kws):
     """create a FloatSpin with Pin button with action"""
+    btnsize = (35, 35) if 'gtk3' in wx.PlatformInfo else (25, 25)
+
     fspin = FloatSpin(parent, value=value, **kws)
     bmbtn = wx.BitmapButton(parent, id=-1, bitmap=get_icon('pin'),
-                            size=(25, 25))
+                            size=btnsize)
     if pin_action is not None:
         parent.Bind(wx.EVT_BUTTON, pin_action, bmbtn)
     bmbtn.SetToolTip(tooltip)
